@@ -455,7 +455,7 @@ setMethod(".font",
 ## font<-
 setReplaceMethod("font",signature(obj="gWidgetRGtk"),
           function(obj, ..., value) {
-            .font(obj, obj@toolkit,...) <- value
+            .font(obj, obj@toolkit,...) <- .fixFontMessUp(value)
             return(obj)
           })
 setReplaceMethod(".font",
